@@ -34,12 +34,9 @@ because it sometimes is used in different senses in other programs"
 Biopython 1.58 or later treats dots/periods in the sequence as invalid, both
 for reading and writing. Older versions did nothing special with a dot/period.
 """
-from __future__ import print_function
 
 import string
 
-from Bio._py3k import range
-
 from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
 from Bio.Align import MultipleSeqAlignment
@@ -100,9 +97,10 @@ class PhylipWriter(SequentialAlignmentWriter):
             """
             name = sanitize_name(record.id, id_width)
             if name in names:
-                raise ValueError("Repeated name %r (originally %r), "
-                                 "possibly due to truncation"
-                                 % (name, record.id))
+                raise ValueError(
+                    "Repeated name %r (originally %r), possibly due to truncation"
+                    % (name, record.id)
+                )
             names.append(name)
             sequence = str(record.seq)
             if "." in sequence:
@@ -129,9 +127,8 @@ class PhylipWriter(SequentialAlignmentWriter):
                 # Write five chunks of ten letters per line...
                 for chunk in range(0, 5):
                     i = block * 50 + chunk * 10
-                    seq_segment = sequence[i:i + 10]
-                    # TODO - Force any gaps to be '-' character?  Look at the
-                    # alphabet...
+                    seq_segment = sequence[i : i + 10]
+                    # TODO - Force any gaps to be '-' character?
                     # TODO - How to cope with '?' or '.' in the sequence?
                     handle.write(" %s" % seq_segment)
                     if i + 10 > length_of_seqs:
@@ -181,8 +178,8 @@ class PhylipIterator(AlignmentIterator):
         The first 10 characters in the line are are the sequence id, the
         remainder are sequence data.
         """
-        seq_id = line[:self.id_width].strip()
-        seq = line[self.id_width:].strip().replace(' ', '')
+        seq_id = line[: self.id_width].strip()
+        seq = line[self.id_width :].strip().replace(" ", "")
         return seq_id, seq
 
     def __next__(self):
@@ -207,15 +204,18 @@ class PhylipIterator(AlignmentIterator):
             number_of_seqs = int(parts[0])
             length_of_seqs = int(parts[1])
         except ValueError:
-            raise ValueError("First line should have two integers")
+            raise ValueError("First line should have two integers") from None
 
         assert self._is_header(line)
 
-        if self.records_per_alignment is not None and \
-                self.records_per_alignment != number_of_seqs:
-            raise ValueError("Found %i records in this alignment, "
-                             "told to expect %i"
-                             % (number_of_seqs, self.records_per_alignment))
+        if (
+            self.records_per_alignment is not None
+            and self.records_per_alignment != number_of_seqs
+        ):
+            raise ValueError(
+                "Found %i records in this alignment, told to expect %i"
+                % (number_of_seqs, self.records_per_alignment)
+            )
 
         ids = []
         seqs = []
@@ -258,10 +258,11 @@ class PhylipIterator(AlignmentIterator):
             if not line:
                 break  # end of file
 
-        records = (SeqRecord(Seq("".join(s), self.alphabet),
-                             id=i, name=i, description=i)
-                   for (i, s) in zip(ids, seqs))
-        return MultipleSeqAlignment(records, self.alphabet)
+        records = (
+            SeqRecord(Seq("".join(s)), id=i, name=i, description=i)
+            for (i, s) in zip(ids, seqs)
+        )
+        return MultipleSeqAlignment(records)
 
 
 # Relaxed Phylip
@@ -273,8 +274,7 @@ class RelaxedPhylipWriter(PhylipWriter):
         # Check inputs
         for name in (s.id.strip() for s in alignment):
             if any(c in name for c in string.whitespace):
-                raise ValueError("Whitespace not allowed in identifier: %s"
-                                 % name)
+                raise ValueError("Whitespace not allowed in identifier: %s" % name)
 
         # Calculate a truncation length - maximum length of sequence ID plus a
         # single character for padding
@@ -283,8 +283,8 @@ class RelaxedPhylipWriter(PhylipWriter):
         if len(alignment) == 0:
             id_width = 1
         else:
-            id_width = max((len(s.id.strip()) for s in alignment)) + 1
-        super(RelaxedPhylipWriter, self).write_alignment(alignment, id_width)
+            id_width = max(len(s.id.strip()) for s in alignment) + 1
+        super().write_alignment(alignment, id_width)
 
 
 class RelaxedPhylipIterator(PhylipIterator):
@@ -326,9 +326,10 @@ class SequentialPhylipWriter(SequentialAlignmentWriter):
             # else like an underscore "_" or pipe "|" character...
             name = sanitize_name(record.id, id_width)
             if name in names:
-                raise ValueError("Repeated name %r (originally %r), "
-                                 "possibly due to truncation"
-                                 % (name, record.id))
+                raise ValueError(
+                    "Repeated name %r (originally %r), possibly due to truncation"
+                    % (name, record.id)
+                )
             names.append(name)
 
         # From experimentation, the use of tabs is not understood by the
@@ -383,15 +384,18 @@ class SequentialPhylipIterator(PhylipIterator):
             number_of_seqs = int(parts[0])
             length_of_seqs = int(parts[1])
         except ValueError:
-            raise ValueError("First line should have two integers")
+            raise ValueError("First line should have two integers") from None
 
         assert self._is_header(line)
 
-        if self.records_per_alignment is not None and \
-                self.records_per_alignment != number_of_seqs:
-            raise ValueError("Found %i records in this alignment, "
-                             "told to expect %i"
-                             % (number_of_seqs, self.records_per_alignment))
+        if (
+            self.records_per_alignment is not None
+            and self.records_per_alignment != number_of_seqs
+        ):
+            raise ValueError(
+                "Found %i records in this alignment, told to expect %i"
+                % (number_of_seqs, self.records_per_alignment)
+            )
 
         ids = []
         seqs = []
@@ -411,9 +415,10 @@ class SequentialPhylipIterator(PhylipIterator):
                     continue
                 s = "".join([s, line.strip().replace(" ", "")])
                 if len(s) > length_of_seqs:
-                    raise ValueError("Found a record of length %i, "
-                                     "should be %i"
-                                     % (len(s), length_of_seqs))
+                    raise ValueError(
+                        "Found a record of length %i, "
+                        "should be %i" % (len(s), length_of_seqs)
+                    )
             if "." in s:
                 raise ValueError(_NO_DOTS)
             seqs.append(s)
@@ -426,10 +431,10 @@ class SequentialPhylipIterator(PhylipIterator):
                 self._header = line
                 break
 
-        records = (SeqRecord(Seq(s, self.alphabet),
-                             id=i, name=i, description=i)
-                   for (i, s) in zip(ids, seqs))
-        return MultipleSeqAlignment(records, self.alphabet)
+        records = (
+            SeqRecord(Seq(s), id=i, name=i, description=i) for (i, s) in zip(ids, seqs)
+        )
+        return MultipleSeqAlignment(records)
 
 
 def sanitize_name(name, width=None):
