@@ -2,9 +2,11 @@
 # Revisions 2007-2010 copyright by Peter Cock.  All rights reserved.
 # Revisions 2009 copyright by Brad Chapman.  All rights reserved.
 # Revisions 2013 copyright by Tiago Antao.  All rights reserved.
-# This code is part of the Biopython distribution and governed by its
-# license.  Please see the LICENSE file that should have been included
-# as part of this package.
+#
+# This file is part of the Biopython distribution and governed by your
+# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
+# Please see the LICENSE file that should have been included as part of this
+# package.
 #
 # Note that BioSQL (including the database schema and scripts) is
 # available and licensed separately.  Please consult www.biosql.org
@@ -16,7 +18,7 @@ import os
 _dbutils = {}
 
 
-class Generic_dbutils(object):
+class Generic_dbutils:
     """Default database utilities."""
 
     def __init__(self):
@@ -25,16 +27,16 @@ class Generic_dbutils(object):
 
     def tname(self, table):
         """Return the name of the table."""
-        if table != 'biosequence':
+        if table != "biosequence":
             return table
         else:
-            return 'bioentry'
+            return "bioentry"
 
     def last_id(self, cursor, table):
         """Return the last used id for a table."""
         # XXX: Unsafe without transactions isolation
         table = self.tname(table)
-        sql = r"select max(%s_id) from %s" % (table, table)
+        sql = "select max(%s_id) from %s" % (table, table)
         cursor.execute(sql)
         rv = cursor.fetchone()
         return rv[0]
@@ -102,14 +104,14 @@ class _PostgreSQL_dbutils(Generic_dbutils):
 
     def next_id(self, cursor, table):
         table = self.tname(table)
-        sql = r"select nextval('%s_pk_seq')" % table
+        sql = "SELECT nextval('%s_pk_seq')" % table
         cursor.execute(sql)
         rv = cursor.fetchone()
         return rv[0]
 
     def last_id(self, cursor, table):
         table = self.tname(table)
-        sql = r"select currval('%s_pk_seq')" % table
+        sql = "SELECT currval('%s_pk_seq')" % table
         cursor.execute(sql)
         rv = cursor.fetchone()
         return rv[0]
